==> kjy-center-api-0.0.2-14-20190313.120253-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/RemoteContentService.java <==
package cn.com.duiba.kjy.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.constant.ContentTypeEnum;
import cn.com.duiba.kjy.api.constant.KjyCenterException;
import cn.com.duiba.kjy.api.dto.ContentDto;
import cn.com.duiba.kjy.api.dto.ContentExtDto;
import cn.com.duiba.kjy.api.params.ContentSearchParams;

import java.util.Date;
import java.util.List;

/**
 * Created by zhangshun on 2019/2/13.
 */
@AdvancedFeignClient
public interface RemoteContentService {

    /**
     * 查询文章列表
     * @param contentSearchParams
     * @return
     */
    List<ContentDto> selectList(ContentSearchParams contentSearchParams);

    /**
     * 通过id列表批量查询内容
     * @param ids
     * @return
     */
    List<ContentDto> findByIds(List<Long> ids);

    /**
     * 根据内容id查询内容，包括扩展信息
     * @param id
     * @return
     */
    ContentExtDto findExtByContentId(Long id);

    /**
     * 根据内容id查询内容，包括扩展信息
     * @param id
     * @return
     */
    ContentDto findByContentId(Long id);

    /**
     * 新增内容 包含主体
     * @param contentExtDto
     * @return
     * @throws KjyCenterException
     */
    Long insert(ContentExtDto contentExtDto) throws KjyCenterException;

    /**
     * 跟新内容 包含主体
     * @param contentExtDto
     * @return
     */
    Integer update(ContentExtDto contentExtDto);

    /**
     * 批量删除 包含主体
     * @param ids
     * @return
     */
    Integer bathDelete(List<Long> ids);

    /**
     * 发布/撤回 内容
     * @param id
     * @param open
     * @return
     */
    Integer openContent(Long id, Integer open);

    /**
     * 跟新排序 上移，下移
     * @param id
     * @param sort ： >0 上移 < 0下移
     * @param contentType 内容类型
     * @return
     */
    Integer updateSort(Long id, Integer sort, ContentTypeEnum contentType);

    /**
     * 查询总数
     * @param params
     * @return
     */
    Long selectCount(ContentSearchParams params);

    /**
     * 文章分享次数加1
     * @param contentId
     * @return
     */
    Boolean sharedNumIncrease(Long contentId);

    /**
     * 根据指定日期查询是否存在日报
     * @param releaseTime
     * @return
     */
    ContentDto findDailyByDate(Date releaseTime);

    /**
     * 日报发布
     * @param id
     * @return
     */
    Boolean openDaily(Long id);

    /**
     * 获取发布中的日报
     * @return
     */
    ContentDto selectInitDaily();

}

==> kjy-center-api-0.0.2.35-20190412.022936-1-sources.jar: cn/com/duiba/kjy/api/remoteservice/RemoteContentService.java <==
package cn.com.duiba.kjy.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.kjy.api.constant.ContentTypeEnum;
import cn.com.duiba.kjy.api.constant.KjyCenterException;
import cn.com.duiba.kjy.api.dto.ContentDto;
import cn.com.duiba.kjy.api.dto.ContentExtDto;
import cn.com.duiba.kjy.api.params.ContentSearchParams;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Created by zhangshun on 2019/2/13.
 */
@AdvancedFeignClient
public interface RemoteContentService {

    /**
     * 查询文章列表
     * @param contentSearchParams
     * @return
     */
    List<ContentDto> selectList(ContentSearchParams contentSearchParams);

    /**
     * 通过id列表批量查询内容
     * @param ids
     * @return
     */
    List<ContentDto> findByIds(List<Long> ids);

    /**
     * 根据内容id查询内容，包括扩展信息
     * @param id
     * @return
     */
    ContentExtDto findExtByContentId(Long id);

    /**
     *
     * @param ids
     * @return
     */
    Map<Long, ContentExtDto> findExtByIds(List<Long> ids);

    /**
     * 根据内容id查询内容，包括扩展信息
     * @param id
     * @return
     */
    ContentDto findByContentId(Long id);

    /**
     * 新增内容 包含主体
     * @param contentExtDto
     * @return
     * @throws KjyCenterException
     */
    Long insert(ContentExtDto contentExtDto) throws KjyCenterException;

    /**
     * 跟新内容 包含主体
     * @param contentExtDto
     * @return
     */
    Integer update(ContentExtDto contentExtDto);

    /**
     * 跟新内容 包含主体
     *
     * @deprecated
     * @param status
     * @return
     */
    @Deprecated
    Boolean updateStatus(Long id, Integer status);

    /**
     * 批量删除 包含主体
     * @param ids
     * @return
     */
    Integer bathDelete(List<Long> ids);

    /**
     * 发布/撤回 内容
     * @param id
     * @param open
     * @return
     */
    Integer openContent(Long id, Integer open);

    /**
     * 跟新排序 上移，下移
     * @param id
     * @param sort ： >0 上移 < 0下移
     * @param contentType 内容类型
     * @return
     */
    Integer updateSort(Long id, Integer sort, ContentTypeEnum contentType);

    /**
     * 跟新文章的敏感词检测结果
     * @param id
     * @param suggestion
     * @return
     */
    Integer updateArticleSuggestion(Long id,String suggestion);

    /**
     * 查询总数
     * @param params
     * @return
     */
    Long selectCount(ContentSearchParams params);

    /**
     * 文章分享次数加1
     * @param contentId
     * @return
     */
    Boolean sharedNumIncrease(Long contentId);

    /**
     * 根据指定日期查询是否存在日报
     * @param releaseTime
     * @return
     */
    ContentDto findDailyByDate(Date releaseTime);

    /**
     * 日报发布
     * @param id
     * @return
     */
    Boolean openDaily(Long id);

    /**
     * 获取发布中的日报
     * @return
     */
    ContentDto selectInitDaily();

}
